@@ -1,6 +1,6 @@
 """Agent Resource functions."""
 
-# Copyright 2021 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,9 +16,8 @@
 
 import logging
 from typing import Dict, List
-import requests
 from google.cloud.dialogflowcx_v3beta1 import services
-import google.cloud.dialogflowcx_v3beta1.types as types
+from google.cloud.dialogflowcx_v3beta1 import types
 from google.protobuf import field_mask_pb2
 
 from dfcx_scrapi.core.scrapi_base import ScrapiBase
@@ -103,10 +102,7 @@ class Agents(ScrapiBase):
 
             agents = []
             for region in region_list:
-                location_path = "projects/{}/locations/{}".format(
-                    project_id, region
-                )
-
+                location_path = f"projects/{project_id}/locations/{region}"
                 client, request = self._build_list_agents_client_request(
                     location_path
                 )
@@ -178,9 +174,7 @@ class Agents(ScrapiBase):
 
         elif region:
             agent_list = self.list_agents(
-                location_id="projects/{}/locations/{}".format(
-                    project_id, region
-                    )
+                location_id=f"projects/{project_id}/locations/{region}"
             )
         else:
             agent_list = self.list_agents(project_id=project_id)
@@ -239,13 +233,11 @@ class Agents(ScrapiBase):
 
         if obj:
             agent = obj
-            parent = "projects/{}/location/{}".format(
-                agent.name.split("/")[1], agent.name.split("/")[3]
-            )
+            parent = f"projects/{project_id}/locations/{gcp_region}"
             agent.display_name = display_name
         else:
             agent = types.agent.Agent()
-            parent = "projects/{}/locations/{}".format(project_id, gcp_region)
+            parent = f"projects/{project_id}/locations/{gcp_region}"
             agent.display_name = display_name
 
         agent.default_language_code = "en"
@@ -451,100 +443,4 @@ class Agents(ScrapiBase):
         )
         client.delete_agent(name=agent_id)
 
-        return "Agent '{}' successfully deleted.".format(agent_id)
-
-
-    def validate_agent_rest(self, agent_id: str) -> Dict:
-        """Initiates the Validation of the CX Agent or Flow.
-        *NOTE* THIS METHOD IS BEING DEPRECATED SOON (8/15/21)
-
-        This function will start the Validation feature for the given Agent
-        and then return the results as a Dict.
-
-        Args:
-        agent_id: CX Agent ID string in the following format
-            projects/<PROJECT ID>/locations/<LOCATION ID>/agents/<AGENT ID>
-
-        Returns:
-        results: Dictionary of Validation results for the entire Agent
-            or for the specified Flow.
-        """
-        location = agent_id.split("/")[3]
-        if location != "global":
-            base_url = "https://{}-dialogflow.googleapis.com/v3beta1".format(
-                location
-            )
-        else:
-            base_url = "https://dialogflow.googleapis.com/v3beta1"
-
-        url = "{0}/{1}/validationResult".format(base_url, agent_id)
-        headers = {"Authorization": "Bearer {}".format(self.token)}
-
-        # Make REST call
-        results = requests.get(url, headers=headers)
-        results.raise_for_status()
-
-        return results.json()
-
-
-    def get_validation_result_rest(
-        self,
-        agent_id: str,
-        flow_id: str = None) -> Dict:
-        """Extract Validation Results from CX Validation feature.
-         *NOTE* THIS METHOD IS BEING DEPRECATED SOON (8/15/21)
-
-        This function will get the LATEST validation result run for the given
-        CX Agent or CX Flow. If there has been no validation run on the Agent
-        or Flow, no result will be returned. Use `dfcx.validate` function to
-        run Validation on an Agent/Flow.
-
-        Passing in the Agent ID will provide ALL validation results for
-        ALL flows.
-        Passing in the Flow ID will provide validation results for only
-        that Flow ID.
-
-        Args:
-          agent_id: CX Agent ID string in the following format
-            projects/<PROJECT ID>/locations/<LOCATION ID>/agents/<AGENT ID>
-          flow_id: (Optional) CX Flow ID string in the following format
-            projects/<PROJECT ID>/locations/<LOCATION ID>/agents/<AGENT ID>/
-              flows/<FLOW ID>
-
-        Returns:
-          results: Dictionary of Validation results for the entire Agent
-            or for the specified Flow.
-        """
-
-        if flow_id:
-            location = flow_id.split("/")[3]
-            if location != "global":
-                base_url = (
-                    "https://{}-dialogflow.googleapis.com/v3beta1".format(
-                        location
-                    )
-                )
-            else:
-                base_url = "https://dialogflow.googleapis.com/v3beta1"
-
-            url = "{0}/{1}/validationResult".format(base_url, flow_id)
-        else:
-            location = agent_id.split("/")[3]
-            if location != "global":
-                base_url = (
-                    "https://{}-dialogflow.googleapis.com/v3beta1".format(
-                        location
-                    )
-                )
-            else:
-                base_url = "https://dialogflow.googleapis.com/v3beta1"
-
-            url = "{0}/{1}/validationResult".format(base_url, agent_id)
-
-        headers = {"Authorization": "Bearer {}".format(self.token)}
-
-        # Make REST call
-        results = requests.get(url, headers=headers)
-        results.raise_for_status()
-
-        return results.json()
+        return "Agent '{agent_id}' successfully deleted."
